@@ -1,4 +1,4 @@
-require 'json'
+require 'ffi_yajl'
 require 'chef_zero/endpoints/rest_object_endpoint'
 require 'chef_zero/chef_data/data_normalizer'
 
@@ -7,9 +7,9 @@ module ChefZero
     # /nodes/ID
     class NodeEndpoint < RestObjectEndpoint
       def populate_defaults(request, response_json)
-        node = JSON.parse(response_json, :create_additions => false)
+        node = FFI_Yajl::Parser.parse(response_json, :create_additions => false)
         node = ChefData::DataNormalizer.normalize_node(node, request.rest_path[3])
-        JSON.pretty_generate(node)
+        FFI_Yajl::Encoder.encode(node, :pretty => true)
       end
     end
   end
