@@ -1,4 +1,4 @@
-require 'json'
+require 'ffi_yajl'
 require 'chef_zero'
 require 'chef_zero/rest_base'
 
@@ -29,7 +29,7 @@ module ChefZero
           json_response(200, {
             'name' => name,
             'type' => type,
-            'public_key' => JSON.parse(json)['public_key'] || PUBLIC_KEY,
+            'public_key' => FFI_Yajl::Parser.parse(json)['public_key'] || PUBLIC_KEY,
             'authz_id' => '0'*32,
             'org_member' => org_member
           })
