@@ -178,7 +178,11 @@ module ChefZero
     end
 
     def json_response(response_code, json)
-      already_json_response(response_code, JSON.pretty_generate(json))
+      already_json_response(response_code, FFI_Yajl::Encoder.encode(json, :pretty => true))
+    end
+
+    def text_response(response_code, text)
+      [response_code, {"Content-Type" => "text/plain"}, text]
     end
 
     def already_json_response(response_code, json_text)
@@ -191,8 +195,9 @@ module ChefZero
         # Strip off /organizations/chef if we are in single org mode
         if rest_path[0..1] != [ 'organizations', server.options[:single_org] ]
           raise "Unexpected URL #{rest_path[0..1]} passed to build_uri in single org mode"
+        else
+          "#{base_uri}/#{rest_path[2..-1].join('/')}"
         end
-        "#{base_uri}/#{rest_path[2..-1].join('/')}"
       else
         "#{base_uri}/#{rest_path.join('/')}"
       end
