@@ -27,6 +27,7 @@ require 'webrick'
 require 'webrick/https'
 
 require 'chef_zero'
+require 'chef_zero/socketless_server_map'
 require 'chef_zero/chef_data/cookbook_data'
 require 'chef_zero/chef_data/acl_path'
 require 'chef_zero/rest_router'
@@ -69,6 +70,7 @@ require 'chef_zero/endpoints/organization_users_endpoint'
 require 'chef_zero/endpoints/organization_user_endpoint'
 require 'chef_zero/endpoints/organization_validator_key_endpoint'
 require 'chef_zero/endpoints/principal_endpoint'
+require 'chef_zero/endpoints/policies_endpoint'
 require 'chef_zero/endpoints/role_endpoint'
 require 'chef_zero/endpoints/role_environments_endpoint'
 require 'chef_zero/endpoints/sandboxes_endpoint'
@@ -82,9 +84,11 @@ require 'chef_zero/endpoints/user_association_request_endpoint'
 require 'chef_zero/endpoints/user_organizations_endpoint'
 require 'chef_zero/endpoints/file_store_file_endpoint'
 require 'chef_zero/endpoints/not_found_endpoint'
+require 'chef_zero/endpoints/version_endpoint'
 
 module ChefZero
   class Server
+
     DEFAULT_OPTIONS = {
       :host => '127.0.0.1',
       :port => 8889,
@@ -94,6 +98,11 @@ module ChefZero
       :ssl => false
     }.freeze
 
+    GLOBAL_ENDPOINTS = [
+      '/license',
+      '/version',
+    ]
+
     def initialize(options = {})
       @options = DEFAULT_OPTIONS.merge(options)
       if @options[:single_org] && !@options.has_key?(:osc_compat)
@@ -101,6 +110,7 @@ module ChefZero
       end
       @options.freeze
       ChefZero::Log.level = @options[:log_level].to_sym
+      @app = nil
     end
 
     # @return [Hash]
@@ -139,6 +149,12 @@ module ChefZero
                end
     end
 
+    def local_mode_url
+      raise "Port not yet set, cannot generate URL" unless port.kind_of?(Integer)
+      "chefzero://localhost:#{port}"
+    end
+
+
     #
     # The data store for this server (default is in-memory).
     #
@@ -217,7 +233,6 @@ module ChefZero
       thread.join
     end
 
-
     #
     # Start a Chef Zero server in a forked process. This method returns the PID
     # to the forked process.
@@ -239,6 +254,7 @@ module ChefZero
           @running = true
         }
       )
+      ENV['HTTPS'] = 'on' if options[:ssl]
       @server.mount('/', Rack::Handler::WEBrick, app)
 
       # Pick a port
@@ -276,9 +292,19 @@ module ChefZero
         sleep(0.01)
       end
 
+      SocketlessServerMap.instance.register_port(@port, self)
+
       @thread
     end
 
+    def start_socketless
+      @port = SocketlessServerMap.instance.register_no_listen_server(self)
+    end
+
+    def handle_socketless_request(request_env)
+      app.call(request_env)
+    end
+
     #
     # Boolean method to determine if the server is currently ready to accept
     # requests. This method will attempt to make an HTTP request against the
@@ -307,6 +333,7 @@ module ChefZero
       if @thread
         ChefZero::Log.error("Chef Zero did not stop within #{wait} seconds! Killing...")
         @thread.kill
+        SocketlessServerMap.deregister(port)
       end
     ensure
       @server = nil
@@ -357,7 +384,6 @@ module ChefZero
     #   }
     # }
     def load_data(contents, org_name = nil)
-      passed_org = !!org_name
       org_name ||= options[:single_org]
       if org_name.nil? && contents.keys != [ 'users' ]
         raise "Must pass an org name to load_data or run in single_org mode"
@@ -423,7 +449,7 @@ module ChefZero
           end
           raise "No version specified" if !cookbook_data[:version]
           data_store.create_dir(['organizations', org_name, 'cookbooks'], cookbook_data[:cookbook_name], :recursive)
-          data_store.set(['organizations', org_name, 'cookbooks', cookbook_data[:cookbook_name], cookbook_data[:version]], JSON.pretty_generate(cookbook_data), :create)
+          data_store.set(['organizations', org_name, 'cookbooks', cookbook_data[:cookbook_name], cookbook_data[:version]], FFI_Yajl::Encoder.encode(cookbook_data, :pretty => true), :create)
           cookbook_data.values.each do |files|
             next unless files.is_a? Array
             files.each do |file|
@@ -494,8 +520,7 @@ module ChefZero
           [ "/organizations/*/*/*/_acl/*", AclEndpoint.new(self) ]
         ]
       end
-      result +
-      [
+      result + [
         # Both
         [ "/organizations/*/clients", ActorsEndpoint.new(self) ],
         [ "/organizations/*/clients/*", ActorEndpoint.new(self) ],
@@ -515,6 +540,7 @@ module ChefZero
         [ "/organizations/*/environments/*/roles/*", EnvironmentRoleEndpoint.new(self) ],
         [ "/organizations/*/nodes", RestListEndpoint.new(self) ],
         [ "/organizations/*/nodes/*", NodeEndpoint.new(self) ],
+        [ "/organizations/*/policies/*/*", PoliciesEndpoint.new(self) ],
         [ "/organizations/*/principals/*", PrincipalEndpoint.new(self) ],
         [ "/organizations/*/roles", RestListEndpoint.new(self) ],
         [ "/organizations/*/roles/*", RoleEndpoint.new(self) ],
@@ -524,13 +550,21 @@ module ChefZero
         [ "/organizations/*/sandboxes/*", SandboxEndpoint.new(self) ],
         [ "/organizations/*/search", SearchesEndpoint.new(self) ],
         [ "/organizations/*/search/*", SearchEndpoint.new(self) ],
+        [ "/version", VersionEndpoint.new(self) ],
 
         # Internal
         [ "/organizations/*/file_store/**", FileStoreFileEndpoint.new(self) ]
       ]
     end
 
+    def global_endpoint?(ep)
+      GLOBAL_ENDPOINTS.any? do |g_ep|
+        ep.start_with?(g_ep)
+      end
+    end
+
     def app
+      return @app if @app
       router = RestRouter.new(open_source_endpoints)
       router.not_found = NotFoundEndpoint.new
 
@@ -539,9 +573,11 @@ module ChefZero
       else
         rest_base_prefix = []
       end
-      return proc do |env|
+      @app = proc do |env|
         begin
-          request = RestRequest.new(env, rest_base_prefix)
+          prefix = global_endpoint?(env['PATH_INFO']) ? [] : rest_base_prefix
+
+          request = RestRequest.new(env, prefix)
           if @on_request_proc
             @on_request_proc.call(request)
           end
@@ -559,6 +595,9 @@ module ChefZero
           # Insert Server header
           response[1]['Server'] = 'chef-zero'
 
+          # Add CORS header
+          response[1]['Access-Control-Allow-Origin'] = '*'
+
           # Puma expects the response to be an array (chunked responses). Since
           # we are statically generating data, we won't ever have said chunked
           # response, so fake it.
@@ -572,6 +611,7 @@ module ChefZero
           end
         end
       end
+      @app
     end
 
     def dejsonize_children(hash)
@@ -583,7 +623,7 @@ module ChefZero
     end
 
     def dejsonize(value)
-      value.is_a?(Hash) ? JSON.pretty_generate(value) : value
+      value.is_a?(Hash) ? FFI_Yajl::Encoder.encode(value, :pretty => true) : value
     end
 
     def get_file(directory, path)
